@@ -34,19 +34,25 @@ class ZebrunnerContext:
 
     @property
     def test_is_active(self) -> bool:
-        return self.test_run_is_active and self.test and self.test.zebrunner_id is not None  # type: ignore
+        return self.test_run_is_active and self.test is not None and self.test.zebrunner_id is not None
 
     @property
     def test_run_is_active(self) -> bool:
-        return self.settings and self.test_run and self.test_run.zebrunner_id is not None  # type: ignore
+        return self.test_run is not None and self.test_run.zebrunner_id is not None
 
     @property
     def test_id(self) -> int:
-        return self.test.zebrunner_id if self.test_is_active else None  # type: ignore
+        if self.test is not None and self.test.zebrunner_id is not None:
+            return self.test.zebrunner_id
+        else:
+            raise ValueError("Test id not found.")
 
     @property
     def test_run_id(self) -> int:
-        return self.test_run.zebrunner_id if self.test_run_is_active else None  # type: ignore
+        if self.test_run is not None and self.test_run.zebrunner_id is not None:
+            return self.test_run.zebrunner_id
+        else:
+            raise ValueError("Test-run id not found")
 
 
 zebrunner_context = ZebrunnerContext()
