@@ -4,6 +4,7 @@ import warnings
 from _pytest.config import Config
 from pydantic import ValidationError
 
+from pytest_zebrunner.context import zebrunner_context
 from pytest_zebrunner.hooks import PytestHooks, XdistHooks
 from pytest_zebrunner.settings import load_settings
 
@@ -14,6 +15,7 @@ def pytest_configure(config: Config) -> None:
 
     try:
         settings = load_settings()
+        zebrunner_context.settings = settings
     except ValidationError as exc:
         field_errors = "\n".join([f"\033[93m {e['loc'][0]}\033[0m - {e['msg']}" for e in exc.errors()])
         warnings.warn(
